in execute_command(), call terminal_init() instead of just
disable_signals() after executing the command, as the command may have
changed the terminal settings


git-svn-id: svn://svn.savannah.gnu.org/nano/trunk/nano@4201 35c25a1d-7b9e-4130-9fde-d3aeb78583b8
diff --git a/src/text.c b/src/text.c
index 0ec884d..166c182 100644
--- a/src/text.c
+++ b/src/text.c
@@ -503,9 +503,10 @@
     if (!sig_failed && sigaction(SIGINT, &oldaction, NULL) == -1)
 	nperror("sigaction");
 
     /* Disable interpretation of the special control keys so that we can
      * use Ctrl-C for other things. */
-    disable_signals();
+    terminal_init();
 
     return TRUE;
 }
@@ -503,9 +503,10 @@
 	nperror("sigaction");
 
-    /* Disable interpretation of the special control keys so that we can
+    /* Restore the terminal to its previous state.  In the process,
+     * disable interpretation of the special control keys so that we can
      * use Ctrl-C for other things. */